@@ -10,15 +10,27 @@ class WelcomeCard():
         self.server : str = None
 
     async def create(self):  
-        bgc = await load_image_async('https://raw.githubusercontent.com/Maxi-TM/maxi-card.py/main/maxicard/imgs/bg-welcome.png')
-        background = Editor(bgc).resize((552, 156))
+        background = Editor(Canvas((552, 156), color="#181818"))
 
         font_directory = os.path.join(os.path.dirname(__file__), "fonts")
         font_path = os.path.join(font_directory, "SFMono.ttf")
 
         sfmono = Font(font_path, size=22)
+
         background.text(
-            (159, 12),
+            (16, 12),
+            f"~/discord",
+            font=sfmono,
+            color="#01ed01",
+        )
+        background.text(
+            (140, 12),
+            f"$",
+            font=sfmono,
+            color="#c1c1c1",
+        )
+        background.text(
+            (169, 12),
             f"fetch {self.member.id}",
             font=sfmono,
             color="#c1c1c1",
@@ -30,7 +42,13 @@ class WelcomeCard():
             color="#c1c1c1",
         )
         background.text(
-            (159, 38),
+            (140, 44),
+            f":",
+            font=sfmono,
+            color="#c1c1c1",
+        )
+        background.text(
+            (169, 38),
             f"{self.member}",
             font=sfmono,
             color="#c1c1c1",
@@ -42,7 +60,13 @@ class WelcomeCard():
             color="#c1c1c1",
         )
         background.text(
-            (159, 67),
+            (140, 71),
+            f":",
+            font=sfmono,
+            color="#c1c1c1",
+        )
+        background.text(
+            (169, 67),
             f"{self.datetime}",
             font=sfmono,
             color="#c1c1c1",
@@ -54,19 +78,31 @@ class WelcomeCard():
             color="#c1c1c1",
         )
         background.text(
-            (159, 94),
+            (140, 100),
+            f":",
+            font=sfmono,
+            color="#c1c1c1",
+        )
+        background.text(
+            (169, 94),
             f"Joined the server",
             font=sfmono,
             color="#2dc970",
         )
         background.text(
-            (16, 123),
+            (16, 124),
             f"members",
             font=sfmono,
             color="#c1c1c1",
         )
         background.text(
-            (159, 124),
+            (140, 128),
+            f":",
+            font=sfmono,
+            color="#c1c1c1",
+        )
+        background.text(
+            (169, 124),
             f"{self.server.member_count}",
             font=sfmono,
             color="#c1c1c1",
@@ -83,15 +119,26 @@ class LeaveCard():
         self.server : str = None
 
     async def create(self):  
-        bgc = await load_image_async('https://raw.githubusercontent.com/Maxi-TM/maxi-card.py/main/maxicard/imgs/bg-welcome.png')
-        background = Editor(bgc).resize((552, 156))
+        background = Editor(Canvas((552, 156), color="#181818"))
 
         font_directory = os.path.join(os.path.dirname(__file__), "fonts")
         font_path = os.path.join(font_directory, "SFMono.ttf")
 
         sfmono = Font(font_path, size=22)
         background.text(
-            (159, 12),
+            (16, 12),
+            f"~/discord",
+            font=sfmono,
+            color="#01ed01",
+        )
+        background.text(
+            (140, 12),
+            f"$",
+            font=sfmono,
+            color="#c1c1c1",
+        )
+        background.text(
+            (169, 12),
             f"fetch {self.member.id}",
             font=sfmono,
             color="#c1c1c1",
@@ -103,7 +150,13 @@ class LeaveCard():
             color="#c1c1c1",
         )
         background.text(
-            (159, 38),
+            (140, 44),
+            f":",
+            font=sfmono,
+            color="#c1c1c1",
+        )
+        background.text(
+            (169, 38),
             f"{self.member}",
             font=sfmono,
             color="#c1c1c1",
@@ -115,7 +168,13 @@ class LeaveCard():
             color="#c1c1c1",
         )
         background.text(
-            (159, 67),
+            (140, 71),
+            f":",
+            font=sfmono,
+            color="#c1c1c1",
+        )
+        background.text(
+            (169, 67),
             f"{self.datetime}",
             font=sfmono,
             color="#c1c1c1",
@@ -127,7 +186,13 @@ class LeaveCard():
             color="#c1c1c1",
         )
         background.text(
-            (159, 94),
+            (140, 100),
+            f":",
+            font=sfmono,
+            color="#c1c1c1",
+        )
+        background.text(
+            (169, 94),
             f"Left the server",
             font=sfmono,
             color="#e44b3b",
@@ -139,7 +204,13 @@ class LeaveCard():
             color="#c1c1c1",
         )
         background.text(
-            (159, 124),
+            (140, 128),
+            f":",
+            font=sfmono,
+            color="#c1c1c1",
+        )
+        background.text(
+            (169, 124),
             f"{self.server.member_count}",
             font=sfmono,
             color="#c1c1c1",
@@ -154,8 +225,11 @@ class DeleteCard():
         self.avatar : str = None
 
     async def create(self):
-        bgc = await load_image_async('https://raw.githubusercontent.com/Maxi-TM/maxi-card.py/main/maxicard/imgs/delete-bg.png')
-        background = Editor(bgc).resize((1280, 609))
+
+        img_directory = os.path.join(os.path.dirname(__file__), "imgs")
+        img_path = os.path.join(img_directory, "delete-bg.png")
+
+        background = Editor(img_path).resize((1280, 609))
         if(self.avatar != None):
             profile = await load_image_async(str(self.avatar))
             profile = Editor(profile).resize((334, 334))
@@ -170,8 +244,11 @@ class TrashCard():
         self.avatar : str = None
 
     async def create(self):
-        bgc = await load_image_async('https://raw.githubusercontent.com/Maxi-TM/maxi-card.py/main/maxicard/imgs/trash-bg.jpg')
-        background = Editor(bgc).resize((1080, 583))
+
+        img_directory = os.path.join(os.path.dirname(__file__), "imgs")
+        img_path = os.path.join(img_directory, "trash-bg.png")
+
+        background = Editor(img_path).resize((1080, 583))
         if(self.avatar != None):
             profile = await load_image_async(str(self.avatar))
             profile = Editor(profile).resize((180, 180))
@@ -186,8 +263,11 @@ class WantedCard():
         self.avatar : str = None
 
     async def create(self):
-        bgc = await load_image_async('https://raw.githubusercontent.com/Maxi-TM/maxi-card.py/main/maxicard/imgs/wanted-bg.png')
-        background = Editor(bgc).resize((736, 959))
+
+        img_directory = os.path.join(os.path.dirname(__file__), "imgs")
+        img_path = os.path.join(img_directory, "wanted-bg.png")
+
+        background = Editor(img_path).resize((736, 959))
         if(self.avatar != None):
             profile = await load_image_async(str(self.avatar))
             profile = Editor(profile).resize((353, 353))
@@ -202,8 +282,11 @@ class TombstoneCard():
         self.avatar : str = None
 
     async def create(self):
-        bgc = await load_image_async('https://raw.githubusercontent.com/Maxi-TM/maxi-card.py/main/maxicard/imgs/tombstone-bg.png')
-        background = Editor(bgc).resize((400, 313))
+
+        img_directory = os.path.join(os.path.dirname(__file__), "imgs")
+        img_path = os.path.join(img_directory, "tombstone-bg.png")
+
+        background = Editor(img_path).resize((400, 313))
         if(self.avatar != None):
             profile = await load_image_async(str(self.avatar))
             profile = Editor(profile).resize((130, 130))
@@ -218,8 +301,11 @@ class HitlerCard():
         self.avatar : str = None
 
     async def create(self):
-        bgc = await load_image_async('https://raw.githubusercontent.com/Maxi-TM/maxi-card.py/main/maxicard/imgs/hitler-bg.png')
-        background = Editor(bgc).resize((480, 360))
+
+        img_directory = os.path.join(os.path.dirname(__file__), "imgs")
+        img_path = os.path.join(img_directory, "hitler-bg.png")
+
+        background = Editor(img_path).resize((480, 360))
         if(self.avatar != None):
             profile = await load_image_async(str(self.avatar))
             profile = Editor(profile).resize((142, 142))
@@ -234,8 +320,11 @@ class JailCard():
         self.avatar : str = None
 
     async def create(self):
-        bgc = await load_image_async(str(self.avatar))
-        background = Editor(bgc).resize((350, 350))
+
+        img_directory = os.path.join(os.path.dirname(__file__), "imgs")
+        img_path = os.path.join(img_directory, "jail-bg.png")
+
+        background = Editor(img_path).resize((350, 350))
         if(self.avatar != None):
             jail = await load_image_async('https://raw.githubusercontent.com/Maxi-TM/maxi-card.py/main/maxicard/imgs/jail-bg.png')
             jail = Editor(jail).resize((350, 350))
@@ -250,11 +339,13 @@ class PassedCard():
         self.avatar : str = None
 
     async def create(self):
-        bgc = await load_image_async(str(self.avatar))
-        background = Editor(bgc).resize((512, 512))
+
+        img_directory = os.path.join(os.path.dirname(__file__), "imgs")
+        img_path = os.path.join(img_directory, "passed-bg.png")
+
+        background = Editor(img_path).resize((512, 512))
         if(self.avatar != None):
-            passed = await load_image_async('https://raw.githubusercontent.com/Maxi-TM/maxi-card.py/main/maxicard/imgs/passed-bg.png')
-            passed = Editor(passed).resize((512, 512))
+            passed = Editor(img_path).resize((512, 512))
             background.paste(passed.image, (0, 0))
         
         file = File(fp=background.image_bytes, filename="card.png")
